import java.io.File;


public class JemuxCd implements JemuxCommandInterface
{
	public JemuxCd(String[] args, JemuxUser user)
	{
		this.args = args;
		this.user = user;
		init();
	}

	public void init()
	{
		if (args.length==0)
		{
			user.setUserCurrDir(user.getUserHomeDir());
		}
		else
		{
			if (args[0].equals("--help"))
			{
				System.out.println(getHelp());
			}
			else if (args[0].equals(".."))
			{
				File dir = new File(user.getUserCurrDir());

				/* if user is on root directory, can't go down anymore */
				if (user.getUserCurrDir().equals("/"))
				{
					user.setUserCurrDir(user.getUserCurrDir());
				}
				else /* else, user can move to parent directory */
				{
					user.setUserCurrDir(dir.getParent());
				}
			}
			else if (args[0].equals("/"))
			{
				user.setUserCurrDir("/");
			}
			else if (args[0].equals("."))
			{
				user.setUserCurrDir(user.getUserCurrDir());
			}
			else if (args[0].equals("-"))
			{
				user.setUserCurrDir(user.getUserPrevDir());
			}
			else if ((args[0].equals("~"))||(args[0].equals("--")))
			{
				user.setUserCurrDir(user.getUserHomeDir());
				/* TODO: add support for "cd ~user" (we'll need a JemuxUser array) */
			}
			else
			{
				File dir;
				if (args[0].charAt(0)=='/')
				{
					dir = new File(user.getRealPath()+args[0]);
					if (dir.exists())
					{
						if (!dir.isDirectory())
						{
							System.err.println("cd: "+args[0]+": Not a directory");
						}
						else
						{
							user.setUserCurrDir(args[0]);
						}
					}
					else
					{
						System.err.println("cd: "+args[0]+": No such file or directory");
					}
				}
				else
				{
					String dirname;
					if (user.getUserCurrDir().equals("/"))
					{
						dirname = user.getUserCurrDir()+args[0];
					}
					else
					{
						dirname = user.getUserCurrDir()+"/"+args[0];
					}

					dir = new File(user.getRealPath()+dirname);
					if (dir.exists())
					{
						/* if not a directory, get an error */
						if (!dir.isDirectory())
						{
							System.err.println("cd: "+dirname+": Not a directory");
						}
						else
						{
							user.setUserCurrDir(dirname);
						}
					}
					else
					{
						System.err.println("cd: "+dirname+": No such file or directory");
					}
				}
			}
		}
	}

	public String getHelp()
	{
		return "[cd] - this commands moves to a new directory\n" +
			"usage:   cd <directory>";
	}

	private String[] args;
	private JemuxUser user;
}
