/**
	Minimalistic JEmuX's UNIX-like shell.
*/


import java.util.*;


public class JemuxShell
{
	String userName;
	String userGroup;
	int UID;
	int GID;
	String homeDirectory;		// user's home directory
	String currDirectory;		// user's current directory
	String userShell;
	String hostname;
	String cmdLineText;
	int MAXCMDLINELEN = 1024;	// max command line's length is 1024 chars
	JemuxShellParser parser;
	JemuxUser user;
	boolean exitStatus;

	public JemuxShell(JemuxUser user, String hostname)
	{
		this.user = user;
		this.hostname = hostname;
		userName = user.getUserName();
		userGroup = user.getUserGroup();
		UID = user.getUID();
		GID = user.getGID();
		homeDirectory = user.getUserHomeDir();
		currDirectory = user.getUserHomeDir();
		showMOTD();
		exitStatus = false;
	}

	private void showMOTD()
	{
		System.out.println();
		System.out.println();
		new JemuxMOTD();
		System.out.println();
	}

	public void getShellPrompt()
	{
		String dir;

		currDirectory = user.getUserCurrDir();

		if (currDirectory.equals(homeDirectory))
		{
			dir = "~";
		}
		else if (currDirectory.contains(homeDirectory))
		{
			dir = currDirectory.replace(homeDirectory, "~");
		}
		else
		{
			dir = currDirectory;
		}

		String prompt = userName+"@"+hostname+":"+dir+((UID==0)?"# ":"$ ");
		System.out.print('\n'+prompt);
		/* TODO: modify the prompt with "export PS1" using String method replace() */
	}

	public void getCmdLineArguments()
	{
		getShellPrompt();
		cmdLineText = Console.readLine();

		if (cmdLineText.length()>MAXCMDLINELEN)
		{
			System.err.println("Command line too long!");
			System.exit(-1); //!!! USE AN EXCEPTION INSTEAD OF THIS!!!
		}
	}

	public boolean getExitStatus()
	{
		return exitStatus;
	}

	public String getCmdLineText()
	{
		return cmdLineText;
	}
}
