/**
	An easy interface to read numbers and strings from
	standard input
	@version 1.10 10 Mar 1997
	@author Cay Horstmann
*/

import java.io.*;
//import javax.security.auth.callback.PasswordCallback;


public class Console
{
	/**
		Prints a prompt on the console but doesn't print a newline.
		@param prompt the prompt string to display
	*/

	public static void printPrompt(String prompt)
	{
		System.out.print(prompt+" ");
		System.out.flush();
	}

	/**
		Reads a string from the console. The string is terminated by a newline.
		@return the input string (without the newline)
	*/

	public static String readLine()
	{
		int ch;
		String r = "";
		boolean done = false;
		while (!done)
		{
			try {
				ch = System.in.read();
				if ((ch<0)||((char)ch=='\n'))
					done = true;
				else if ((char)ch!='\r')
					r = r + (char)ch;
			} catch (java.io.IOException e) {
				done = true;
			}
		}
		return r;
	}

	/**
		Reads a string from the console. The string is terminated by a newline.
		@param prompt the prompt string to display
		@return the input string (without the newline)
	*/

	public static String readLine(String prompt)
	{
		printPrompt(prompt);
		return readLine();
	}

	/**
		Reads a single word from the console.
		@return the input string as a single word
		@exception IOException
	*/

	public static String readWord()
	{
		int ch;
		String r = "";
		boolean done = false;
		while (!done)
		{
			try {
				ch = System.in.read();
				if ((ch<0)||(java.lang.Character.isWhitespace((char)ch)))
					done = true;
				else
					r = r + (char)ch;
			} catch (java.io.IOException e) {
				done = true;
			}
		}
		return r;
	}

	/**
		Reads a password from the console without echoing characters.
		@param prompt the prompt string to display
		@return the input string
		@exception IOException
	*/

	public static String readPassword(String prompt)
	{
		PasswordField passfield = new PasswordField();
		String password = null;
		try {
			password = passfield.getPassword(prompt);
		} catch (IOException ioe) {
			ioe.printStackTrace();
		}
		return password;
	}

	/**
		Reads an integer from the console. The input is terminated by a newline.
		@param prompt the prompt string to display
		@return the input value as an int
		@exception NumberFormatException if bad input
	*/

	public static int readInt(String prompt)
	{
		while (true)
		{
			printPrompt(prompt);
			try {
				return Integer.valueOf(readLine().trim()).intValue();
			} catch (NumberFormatException e) {
				System.out.println("Not an integer. Please try again!");
			}
		}
	}

	/**
		Reads a floating point number from the console. The input is terminated by a newline.
		@param prompt the prompt string to display
		@return the input value as a double
		@exception NumberFormatException if bad input
	*/

	public static double readDouble(String prompt)
	{
		while (true)
		{
			printPrompt(prompt);
			try {
				return Double.parseDouble(readLine().trim());
			} catch (NumberFormatException e) {
				System.out.println("Not a floating point number. Please try again!");
			}
		}
	}
}
