import java.util.*;


public class JemuxFile
{
	String fileName;
	int fileSize;
	String fileCreationDate;
	String fileCreationTime;
	String fileOwner;
	String fileGroup;
	char fileFlag;
	int ownerPermissions;
	int groupPermissions;
	int otherPermissions;
	boolean hidden;

	/**
		Constructor for a generic file.
		@param fN, file name (which begins with "." if hidden)
		@param fO, file owner
		@param fG, file group
		@param fF, file flag ('n' for normal file, 'd' for directory, 'l' for link)
		@param uP, user's permissions (in octal format from 0 to 7)
		@param gP, group's permissions (in octal format from 0 to 7)
		@param oP, other's permissions (in octal format from 0 to 7)
	*/

	public JemuxFile(String fN, String fO, String fG, char fF, int uP, int gP, int oP)
	{
		Date fCD = new Date();
		fileName = fN;
		fileFlag = fF;
		fileCreationDate = fCD.toString();
		fileOwner = fO;
		fileGroup = fG;
		ownerPermissions = uP;
		groupPermissions = gP;
		otherPermissions = oP;
		hidden = (fileName.charAt(0)=='.');
	}

	public String getFileName()
	{
		return fileName;
	}

	public String getFileCreationDate()
	{
		return fileCreationDate;
	}

	public String getFileOwner()
	{
		return fileOwner;
	}

	public String getFileGroup()
	{
		return fileGroup;
	}

	public char getFileFlag()
	{
		if (fileFlag=='n') fileFlag = '-';
		return fileFlag;
	}

	public String getOwnerPermString()
	{
		return permNumToString(ownerPermissions);
	}

	public String getGroupPermString()
	{
		return permNumToString(groupPermissions);
	}

	public String getOtherPermString()
	{
		return permNumToString(otherPermissions);
	}

	private String permNumToString(int n)
	{
		String perm = "?";
			 if (n==0) perm = "---";
		else if (n==1) perm = "--x";
		else if (n==2) perm = "-w-";
		else if (n==3) perm = "-wx";
		else if (n==4) perm = "r--";
		else if (n==5) perm = "r-x";
		else if (n==6) perm = "rw-";
		else if (n==7) perm = "rwx";
		//else System.out.println("Wrong value!"); //throws exception
		return perm;
	}

	public void printLsFileInfoLongFormat() // equals "ls -la"
	{
		System.out.println(getFileFlag() +
						   getOwnerPermString() +
						   getGroupPermString() +
						   getOtherPermString() +
						   "   " +
						   getFileOwner() +
						   " " +
						   getFileGroup() +
						   "   " +
						   getFileCreationDate() +
						   "   " +
						   getFileName());
	}
}