import java.io.*;
import java.net.URL;


public class JemuxFileHandler
{
	public JemuxFileHandler()
	{
	}

	/**
		Show the contents of the file 'fileName' on stdout.
		@param fileName The name of the file to show
		@throws IOException if the file could not be opened
	*/

	public void showFile(String fileName) throws IOException
	{
		InputStream fstream = openFileI(fileName);
		BufferedReader in = new BufferedReader(new InputStreamReader(fstream));
		String line = in.readLine();

		while (line!=null) {
			System.out.println(line);
			line = in.readLine();
		}
		fstream.close();
		in.close();
	}

	/**
		Show the contents of the file 'fileName' on stdout.
		@param fileName The name of the file to show
		@throws IOException if the file could not be opened
	*/

	public String[] getFileContent(String fileName) throws IOException
	{
		String[] line = new String[getFileLinesNumber(fileName)];
		InputStream fstream = openFileI(fileName);
		BufferedReader in = new BufferedReader(new InputStreamReader(fstream));
		int i = 0;

		String temp = in.readLine();
		while (temp!=null) {
			line[i] = temp;
			i++;
			temp = in.readLine();
		}
		fstream.close();
		in.close();

		return line;
	}

	/**
		Write a string of text on file 'fileName'.
		@param fileName The name of the file to write in
		@param text Text string to get wrote
		@throws IOException if the file could not be opened
	*/

	public void writeOnFile(String fileName, String text) throws IOException
	{
		OutputStream fstream = openFileO(fileName);
		BufferedWriter out = new BufferedWriter(new OutputStreamWriter(fstream));
		int i = 0;

		out.write(text, 0, text.length());

		fstream.close();
		out.close();
	}

	/**
		Show the contents of the file 'fileName' on stdout.
		@param fileName The name of the file to show
		@throws IOException if the file could not be opened
	*/

	public int getFileLinesNumber(String fileName) throws IOException
	{
		InputStream fstream = openFileI(fileName);
		BufferedReader in = new BufferedReader(new InputStreamReader(fstream));
		int n = 0;

		while (in.readLine()!=null) {
			n++;
		}
		fstream.close();
		in.close();

		return n;
	}

	/**
		Same as 'showFile()', but don't throw exceptions.
		If an error occurs, write an error message to the terminal.
		@param fileName The name of the file to show
	*/

	public void checkedShowFile(String fileName)
	{
		try {
			showFile(fileName);
        } catch (IOException exc) {
			System.err.println("There was a problem showing this file.");
			System.err.println("The error encountered is:");
			System.err.println(exc);
		}
	}

	/**
		Open a text file and return a stream to read from that file.
		The file can reside anywhere in the classpath.
		@param fileName The name of the file to open
		@return An open stream to read from the file
		@throws IOException if the file could not be opened
	*/

	public InputStream openFileI(String fileName) throws IOException
	{
		if (fileName==null) throw new IOException("Cannot open file - filename was null.");
		URL url = getClass().getClassLoader().getResource(fileName);
		if (url==null) throw new IOException("File not found: "+fileName);
		return url.openStream();
	}

	/**
		Open a text file and return a stream to read from that file.
		The file can reside anywhere in the classpath.
		@param fileName The name of the file to open
		@return An open stream to read from the file
		@throws IOException if the file could not be opened
	*/

	public OutputStream openFileO(String fileName) throws IOException
	{
		if (fileName==null) throw new IOException("Cannot open file - filename was null.");
		URL url = getClass().getClassLoader().getResource(fileName);
		if (url==null) throw new IOException("File not found: "+fileName);
		return null;
	}
}
