/**
	Minimalistic JEmuX's UNIX-like shell's command line parser.
*/


import java.util.*;


public class JemuxShellParser
{
	String commands;
	String[] cmdLineArgs;

	public JemuxShellParser(String cmds)
	{
		commands = cmds;
		parseCmdLineArgs();
	}


	/**
		This method counts the number of white spaces in the command line string,
		including the ones between quotes.
		Number of white spaces also means the maximum number of possible commands
		and/or arguments and/or parameters of the command line.
	*/

	private int countWhiteSpaces(String commands)
	{
		int i;
		int whiteSpaces = 1;
		for (i=0; i<commands.length(); i++)
		{
			if (commands.charAt(i)==' ') whiteSpaces++;
		}
		cmdLineArgs = new String[whiteSpaces]; // this means "at least one command"
		return whiteSpaces;
	}


	/**
		This method parses the whole command line, splitting each argument when
		a white space is found, and storing it in a strings array.
	*/

	private void parseCmdLineArgs()
	{
		int numSpaces = countWhiteSpaces(commands); // maximum number of possible arguments
		TOKENS = new String[numSpaces];
		StringTokenizer tokenizer = new StringTokenizer(commands, " ");
		int k = 0;

		while (tokenizer.hasMoreTokens())
		{
			TOKENS[k] = tokenizer.nextToken(); // assuming first token is a command
			if (TOKENS[k].charAt(0)=='"') // recognizing double quotes
			{
				String dqTOKEN = TOKENS[k];
				while ((tokenizer.hasMoreTokens())&&(dqTOKEN.charAt(dqTOKEN.length()-1)!='"'))
				{
					dqTOKEN = dqTOKEN + ' ' + tokenizer.nextToken();
				}
				TOKENS[k] = dqTOKEN;
			}
			else if (TOKENS[k].charAt(0)=='\'') // recognizing single quotes
			{
				String dqTOKEN = TOKENS[k];
				while ((tokenizer.hasMoreTokens())&&(dqTOKEN.charAt(dqTOKEN.length()-1)!='\''))
				{
					dqTOKEN = dqTOKEN + ' ' + tokenizer.nextToken();
				}
				TOKENS[k] = dqTOKEN;
			}
			else if (TOKENS[k].charAt(0)=='`') // recognizing back quotation
			{
				String dqTOKEN = TOKENS[k];
				while ((tokenizer.hasMoreTokens())&&(dqTOKEN.charAt(dqTOKEN.length()-1)!='`'))
				{
					dqTOKEN = dqTOKEN + ' ' + tokenizer.nextToken();
				}
				TOKENS[k] = dqTOKEN;
			}
			k++;
		}

		// for debugging
		/*for (int i=0; i<numSpaces; i++) {
			System.out.println(TOKENS[i]);
		}*/

		// this erases those entries which eventually point to null

	}
	
	public String[] getCommand()
	{
		return TOKENS;
	}

	private String[] TOKENS;
}
